@@ -22,6 +22,6 @@ double NAI_Cpp(const NumericVector & X, double k) {
       Rf_choose(j - 1, k - 1);
   }
 
-  return sqrt(n) * (T2 - T3) / (n * Rf_choose(n, k));
+  return sqrt((double)n) * (T2 - T3) / (n * Rf_choose(n, k));
 }
 
